library(testthat)
library(geomander)

test_check('geomander')
